@@ -16,6 +16,8 @@ from .api import (
     DmsAPI,
     APIPermissionAPI,
     ScheduleAPI,
+    ReactionAPI,
+    PinsAPI,
 )
 
 from .async_api import (
@@ -34,6 +36,7 @@ from .async_api import (
     AsyncDmsAPI,
     AsyncAPIPermissionAPI,
     AsyncScheduleAPI,
+    AsyncReactionAPI,
 )
 from .core.network.ws.ws_intents_handler import HandlerType, Handler
 from .core.util import logging
