@@ -4,8 +4,6 @@
 import json
 from typing import List
 
-import aiohttp
-
 from qqbot import WebsocketAPI
 from qqbot.core.network.async_http import AsyncHttp
 from qqbot.core.network.url import get_url, APIConstant
@@ -16,6 +14,7 @@ from qqbot.model.announce import (
     CreateAnnounceRequest,
     Announce,
     CreateChannelAnnounceRequest,
+    RecommendChannelRequest
 )
 from qqbot.model.api_permission import (
     APIPermission,
@@ -52,6 +51,7 @@ from qqbot.model.message import (
     MessagesPager,
 )
 from qqbot.model.mute import MuteOption
+from qqbot.model.pins_message import PinsMessage
 from qqbot.model.schedule import (
     Schedule,
     GetSchedulesRequest,
@@ -92,9 +92,7 @@ class AsyncAPIBase:
         """
         self.is_sandbox = is_sandbox
         self.token = token
-        self.http_async = AsyncHttp(
-            aiohttp.ClientSession(), self.timeout, token.get_string(), token.get_type()
-        )
+        self.http_async = AsyncHttp(self.timeout, token.get_string(), token.get_type())
 
     def with_timeout(self, timeout):
         self.timeout = timeout
@@ -704,6 +702,20 @@ class AsyncAnnouncesAPI(AsyncAPIBase):
         response = await self.http_async.delete(url)
         return response == ""
 
+    async def post_recommended_channels(
+        self, guild_id: str, request: RecommendChannelRequest
+    ) -> Announce:
+        """
+        创建子频道类型的频道全局公告
+
+        :param guild_id: 频道ID
+        :param request: RecommendChannelRequest 对象
+        """
+        url = get_url(APIConstant.guildAnnounceURI, self.is_sandbox).format(guild_id=guild_id)
+        request_json = JsonUtil.obj2json_serialize(request)
+        response = await self.http_async.post(url, request_json)
+        return json.loads(response, object_hook=Announce)
+
 
 class AsyncAPIPermissionAPI(AsyncAPIBase):
     """接口权限接口"""
@@ -825,3 +837,38 @@ class AsyncScheduleAPI(AsyncAPIBase):
         )
         response = await self.http_async.delete(url)
         return response == ""
+
+
+class AsyncReactionAPI(AsyncAPIBase):
+    """异步表情表态接口"""
+
+    async def put_reaction(self, channel_id: str, message_id: str, emo_type: int, emo_id: str):
+        """
+        对一条消息进行表情表态
+
+        :param channel_id: 子频道ID
+        :param message_id: 该条消息对应的id
+        :param emo_type: 表情类型
+        :param emo_id: 表情ID
+        """
+        url = get_url(APIConstant.reactionURI, self.is_sandbox).format(
+            channel_id=channel_id, message_id=message_id, type=emo_type, id=emo_id
+        )
+        response = await self.http_async.put(url)
+        return response == ""
+
+    async def delete_reaction(self, channel_id: str, message_id: str, emo_type: int, emo_id: str):
+        """
+        删除自己对消息的进行表情表态
+
+        :param channel_id: 子频道ID
+        :param message_id: 该条消息对应的id
+        :param emo_type: 表情类型
+        :param emo_id: 表情ID
+        """
+        url = get_url(APIConstant.reactionURI, self.is_sandbox).format(
+            channel_id=channel_id, message_id=message_id, type=emo_type, id=emo_id
+        )
+        response = await self.http_async.delete(url)
+        return response == ""
+
